<?php

namespace App\Controller;

use App\Entity\Produit;
use App\Entity\Panier;
use App\Repository\ProduitRepository;
use Symfony\Component\HttpFoundation\Response;
use Symfony\Component\Routing\Attribute\Route;
use Doctrine\ORM\EntityManagerInterface;
use Symfony\Bundle\FrameworkBundle\Controller\AbstractController;
use Symfony\Component\HttpFoundation\RequestStack;

class PanierController extends AbstractController
{
    private $entityManager;
    private $requestStack;

    public function __construct(EntityManagerInterface $entityManager, RequestStack $requestStack)
    {
        $this->entityManager = $entityManager;
        $this->requestStack = $requestStack;
    }

    #[Route('/panier', name: 'app_panier_index')]
    public function index(): Response
    {
        $user = $this->getUser();

        if (!$user) {
            return $this->redirectToRoute('app_login');
        }

        $panier = $user->getPanier();

        if (!$panier) {
            $this->addFlash('no-panier', 'Vous n\'avez pas encore de panier !');
            return $this->redirectToRoute('app_home');
        }

        if ($panier->getProduits()->isEmpty()) {
            $this->addFlash('no-panier', 'Votre panier est actuellement vide !');
            return $this->redirectToRoute('app_home');
        }

        $produits = $panier->getProduits();

        return $this->render('panier/index.html.twig', [
            'produits' => $produits,
        ]);
    }


    #[Route('/panier/add/{id}', name: 'app_panier_add')]
    public function add(int $id, ProduitRepository $produitRepository): Response
    {
        $user = $this->getUser();

        if (!$user) {
            return $this->redirectToRoute('app_login');
        }

        $produit = $produitRepository->find($id);
        $panier = $user->getPanier() ?? new Panier();
        $panier->addProduit($produit);

        if (!$user->getPanier()) {
            $panier->setUser($user);
        }

        $this->entityManager->persist($panier);
        $this->entityManager->flush();

        return $this->redirectToRoute('app_panier_index');
    }

    #[Route('/panier/remove/{id}', name: 'app_panier_remove', methods: ['POST'])]
    public function remove(int $id, ProduitRepository $produitRepository): Response
    {
        $user = $this->getUser();

        if (!$user) {
            return $this->redirectToRoute('app_login');
        }

        $produit = $produitRepository->find($id);
        $panier = $user->getPanier();
        $panier->removeProduit($produit);

        $this->entityManager->persist($panier);
        $this->entityManager->flush();

        return $this->redirectToRoute('app_panier_index');
    }

    #[Route('/panier/finalize', name: 'app_panier_finalize', methods: ['POST'])]
    public function finalize(): Response
    {
        $user = $this->getUser();

        if (!$user) {
            return $this->redirectToRoute('app_login');
        }

        $panier = $user->getPanier();
        $panier->getProduits()->clear();

        $this->entityManager->persist($panier);
        $this->entityManager->flush();

        return $this->redirectToRoute('app_home');
    }


}

