<?php

// src/Repository/ProduitRepository.php

namespace App\Repository;

use App\Entity\Produit;
use Doctrine\Bundle\DoctrineBundle\Repository\ServiceEntityRepository;
use Doctrine\Persistence\ManagerRegistry;


/**
 * @extends ServiceEntityRepository<Produit>
 *
 * @method User|null find($id, $lockMode = null, $lockVersion = null)
 * @method User|null findOneBy(array $criteria, array $orderBy = null)
 * @method User[]    findAll()
 * @method User[]    findBy(array $criteria, array $orderBy = null, $limit = null, $offset = null)
 */

class ProduitRepository extends ServiceEntityRepository
{
    public function __construct(ManagerRegistry $registry)
    {
        parent::__construct($registry, Produit::class);
    }

    // Méthode pour filtrer les produits en fonction des critères fournis
    public function findByFilter(?int $prixMin, ?int $prixMax, ?string $date, ?string $auteur, ?string $category ): array
    {
        // Si aucun filtre n'est appliqué, renvoyer tous les produits
        if ($prixMin === null && $prixMax === null && $date === null && $auteur === null) {
            return $this->findAll();
        }

        $query = $this->createQueryBuilder('p');

        if ($prixMin) {
            $query->andWhere('p.prix >= :prixMin')
                ->setParameter('prixMin', $prixMin);
        }

        if ($prixMax) {
            $query->andWhere('p.prix <= :prixMax')
                ->setParameter('prixMax', $prixMax);
        }

        if ($date) {
            $dateObject = \DateTime::createFromFormat('Y-m-d', $date);
            $query->andWhere('p.date = :date')
                ->setParameter('date', $dateObject);
        }

        if ($auteur) {
            $query->andWhere('p.auteur = :auteur')
                ->setParameter('auteur', $auteur);
        }

        if ($category) {
            $query->andWhere('p.category = :category')
                ->setParameter('category', $category);
        }

        return $query->getQuery()->getResult();
    }

    // public function findRandomProducts($limit = 3)
    // {
    //     return $this->createQueryBuilder('p')
    //         ->orderBy('RAND()')
    //         ->setMaxResults($limit)
    //         ->getQuery()
    //         ->getResult();
    // }
}

